pub enum RWUIDW {
_0,
_1,
}Expand description
Values that can be written to the field RWUID
Variants
_0
S1[IDLE] is not set upon detection of an idle character.
_1
S1[IDLE] is set upon detection of an idle character.